Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution. 

## How to Install
```
pip install Topsis-Amrendra-101903414
```

## How to use it?
Open terminal and type `python topsis` along with input file path, weight array, impact array and name of output file. for eg. 
```
python topsis test.csv "1,1,2,3,1" "+,-,+,-,-" output.csv
```


## License
©  2022 Amrendra Pratap Singh
This repository is licensed under the MIT license. See LICENSE for details